; ##############################################################################
; ##############################################################################
; ##############################################################################
STARTWERTE:
	; NULL				
	clr NULL
	; EINS				
	ldi temp,1
	mov EINS,temp
	; VOLL				
	ldi temp,255
	mov VOLL,temp
	; SRAM CHECK		
	ldi temp,'S'
	STS(adr_SRAM_CHECK),temp
	; Error				
	clr ERROR
	; DIGIT off			
	STS(adr_DIGIT7),NULL
	STS(adr_DIGIT6),NULL
	STS(adr_DIGIT5),NULL
	STS(adr_DIGIT4),NULL

	STS(adr_DIGIT3),NULL
	STS(adr_DIGIT2),NULL
	STS(adr_DIGIT1),NULL
	STS(adr_DIGIT0),NULL
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
BEGRUESSUNG:
	; DIGIT Begrssung 28.02.2024	
	ldi temp,(ASCII_2)
	STS(adr_DIGIT7),temp
	ldi temp,(ASCII_8 + ASCII_PUNKT)
	STS(adr_DIGIT6),temp
	ldi temp,(ASCII_0)
	STS(adr_DIGIT5),temp
	ldi temp,(ASCII_2)
	STS(adr_DIGIT4),temp

	ldi temp,(ASCII_2)
	STS(adr_DIGIT3),temp
	ldi temp,(ASCII_0)
	STS(adr_DIGIT2),temp
	ldi temp,(ASCII_2)
	STS(adr_DIGIT1),temp
	ldi temp,(ASCII_4)
	STS(adr_DIGIT0),temp
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
WDR_INITIALISIERUNG:
	ldi TEMP,(1<<WDCE)|(1<<WDE) ; Watchdog aktivieren (max. Zeit)				
	out wdtcr,TEMP       
	ldi TEMP,(1<<WDE) | (1<<WDP2)|(1<<WDP1)|(1<<WDP0) 
	out wdtcr,temp
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
SRAM_CLEAR:
	ldi ZL, LOW (SRAM_START)
	ldi ZH, HIGH(SRAM_START)
	ldi temp,0
;-------------------------------------------------------------------------------
SRAM_CLEAR_w:
	ST z+,temp
	cpi ZH, HIGH(RAMEND-1)	; Vergleich?		
	brlo SRAM_CLEAR_w		; kleiner => SPRUNG	
	cpi ZL, LOW(RAMEND-1)	; Vergleich?		
	brlo SRAM_CLEAR_w		; kleiner => SPRUNG	
	breq SRAM_CLEAR_w		; gleich  => SPRUNG	
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
PORT_INITIALISIERUNG:
	clr temp
	out DDRB, temp
	out DDRC, temp
	out DDRD, temp
	out PORTB,temp				
	out PORTC,temp				
	out PORTD,temp	
;-------------------------------------------------------------------------------
; auf AUSGANG																	
	sbi (BEEP_DDR),(BEEP_PIN_NR)		; BEEP		
	sbi (GRUEN_DDR),(GRUEN_PIN_NR)		; GRN		
	sbi (GELB_DDR) ,(GELB_PIN_NR)		; GELB		
	sbi (ROT_DDR)  ,(ROT_PIN_NR)		; ROT		
;-------------------------------------------------------------------------------
; LED																			
	sbi (CLOCK_DDR),(CLOCK_PIN_NR)		; LED		
	sbi (DAT_DDR)  ,(DAT_PIN_NR)		; LED		
;-------------------------------------------------------------------------------
; Tasten																		
	cbi (TASTE_A_DDR) ,(TASTE_A_PIN_NR)	; Taste A	
	cbi (TASTE_B_DDR) ,(TASTE_B_PIN_NR)	; Taste B	
	sbi (TASTE_A_PORT),(TASTE_A_PIN_NR)	; Pull-Up	
	sbi (TASTE_B_PORT),(TASTE_B_PIN_NR)	; Pull-Up	
;-------------------------------------------------------------------------------
	rcall BEEP_KURZ
	GRUEN_OFF
	GELB_OFF
	ROT_OFF
;-------------------------------------------------------------------------------
	GRUEN_ON
	GELB_ON
	ROT_ON
	rcall wait_1s
	GRUEN_OFF
	GELB_OFF
	ROT_OFF
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
PROGRAMM_CHECK:
	; NULL		
	tst NULL
	brne PROGRAMM_CHECK_ERROR
	; EINS		
	mov temp,EINS
	cpi temp,1
	brne PROGRAMM_CHECK_ERROR
	; VOLL		
	mov temp,VOLL
	cpi temp,255
	brne PROGRAMM_CHECK_ERROR
	; SRAM CHECK
	LDS temp,(adr_SRAM_CHECK)
	cpi temp,'S'
	brne PROGRAMM_CHECK_ERROR
	ret
;-------------------------------------------------------------------------------
PROGRAMM_CHECK_ERROR:
	GRUEN_OFF
	GELB_OFF
	ROT_ON
rjmp PROGRAMM_CHECK_ERROR
; ##############################################################################
; ##############################################################################
; ##############################################################################
TASTEN_WAIT:
	LDS temp,(adr_TASTE)
	tst temp
	brne TASTEN_WAIT_RUN
	ret
;-------------------------------------------------------------------------------
TASTEN_WAIT_RUN:
	rcall WAIT_100ms
	STS(adr_TASTE),NULL
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
BEEP_KURZ:
	BEEP_ON
	rcall WAIT_10ms
	BEEP_OFF	
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
BEEP:
	BEEP_ON
	rcall WAIT_1s
	BEEP_OFF
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; VERSION: 07/2015																
;																				
;	Division 16 bit-Zahl durch 8 bit Zahl										
;																				
;	input/Output 	temp1 (LOW)													
;	input/Output 	temp2 (HIGH)												
;																				
;	input			temp3	Divisor		 										
;																				
DIVISION_16_100:
	ldi temp3,100
	; Hilfsregister sichern		
	push temp6
	push temp7
;-----------------------------------------------------------------------
	; Aufrunden halben Divisor dazuaddieren	
	mov temp,temp3
	LSR temp	
	add temp1,temp
	adc temp2,NULL
;-----------------------------------------------------------------------
	clr temp 			; Leere Hilfsregister
	ldi temp6,1			; Zhler Bit 1 auf 1 setzen)
	clr temp7
;-----------------------------------------------------------------------
div8a:
	clc 				; Carry-Bit leeren
	rol temp1 		
	rol temp2 		
	rol temp 			;  in das Hilfsregister rotieren		
	brcs div8b 			; Eine 1 ist herausgerollt, ziehe ab	
	cp temp,temp3 		; Divisionsergebnis 1 oder 0?			
	brcs div8c 			; berspringe Subtraktion, wenn kleiner	
div8b:
	sub temp,temp3	 	; Subtrahiere Divisor					
	sec 				; Setze carry-bit, Ergebnis ist eine 1	
	rjmp div8d 			
div8c:
	clc 				; Lsche carry-bit, Ergebnis ist eine 0
div8d:
	rol temp6 			; Rotiere carry-bit in das Ergebnis		
	rol temp7
	brcc div8a 			; solange Nullen aus dem Ergebnis rotieren: weitermachen
;-----------------------------------------------------------------------
	;Zurckschreiben	
	mov temp1, temp6
	mov temp2, temp7
;-----------------------------------------------------------------------
	; wieder herstellen	
	pop temp7
	pop temp6
ret
;########################################################################
;########################################################################
;########################################################################
ANZEIGE_ERROR:
	tst ERROR
	brne ANZEIGE_ERROR_RUN
	ret
ANZEIGE_ERROR_RUN:
	rcall BEEP
	rcall WAIT_100ms
ret
;########################################################################
;########################################################################
;########################################################################
